@@ -6,7 +6,7 @@ require "minitest/pride"
 
 Combustion.path = "test/internal"
 Combustion.initialize! :active_record, :action_mailer do
-  if config.active_record.sqlite3.respond_to?(:represent_boolean_as_integer)
+  if ActiveRecord::VERSION::MAJOR < 6 && config.active_record.sqlite3.respond_to?(:represent_boolean_as_integer)
     config.active_record.sqlite3.represent_boolean_as_integer = true
   end
 end
